from setuptools import setup

setup(name='cards_imarshall',
      version='0.1',
      description='Python Card Deck Module',
      url='https://github.com/IanNMarshall/cards_imarshall',
      author='IanNMarshall',
      author_email='ian.nicholas.marshall@gmail.com',
      packages=['cards_imarshall'],
      zip_safe=False)
